macroScript AKNT_Adjust_Turbosmooth
 	category: "AKNToolkit"
 	toolTip: "Adjust Turbosmooth"
 	buttonText: "AdjustTurbosmooth"
 	icon: #("AKNToolkit",7)
(
	(
		clearListener()-- Clean the maxscript listener for testing purpose
		
		local rolloutAdjustTurbosmooth -- Rollout variable for easy access
		local sPathINI = (getFileNamePath (getThisScriptFilename()))+"\\akntoolkit.ini" -- Path to the ini file
		local iMaxIterations = 4 -- Adjust this to set a max amount of iterations you can set with the script

		-- Get the dialog windows position from ini file
		local iRolloutPosX = getINISetting sPathINI "Settings_AdjustTurbosmooth" "rollout_pos_x"
		local iRolloutPosY = getINISetting sPathINI "Settings_AdjustTurbosmooth" "rollout_pos_y"
		iRolloutPosX = if iRolloutPosX == "" then 100 else (iRolloutPosX as Integer) -- If empty, use default value
		iRolloutPosY = if iRolloutPosY == "" then 100 else (iRolloutPosY as Integer) -- If empty, use default value
	)

		
	fn adjust_iterations iVal bSetAll = (
		-- Adjust the objects turbosmooth modifier values to supplied settings:
		-- iVal: The value to set
		-- bSetAll: If true, the iVal will be set to all turbosmooth, if false, the iVal will be add/subtracted to modifiers current value
		local collection = getCurrentSelection() -- Get the current sel
		if collection.count > 0 do -- Only continue if a selection has been done
		(
			-- Loop through each objects
			for obj in collection do
			(
				local firstCheck = true -- Checker for setting if the turbosmooth modifier is the first one on the object
				-- Loop through each modifier to find turbosmooth modifiers
				for m in obj.modifiers where (classOf m) == TurboSmooth do
				(
					local iNewVal = iVal
					if firstCheck == true do
					(
						if (bSetAll == false) do
							iNewVal = m.iterations + iVal
						if (iNewVal < 0) do
							iNewVal = 0
						if (iNewVal > iMaxIterations) do
							iNewVal = iMaxIterations
						m.iterations = iNewVal
						firstCheck = not rolloutAdjustTurbosmooth.chk_firstinstance.checked
					)
				)
			)
		)
	)


	
	fn delete_turbosmooth = (
		local collection = getCurrentSelection()
		if collection.count > 0 do
		(
			-- Loop through each objects
			for obj in collection do
			(
				local firstCheck = true
				for m in obj.modifiers where (classOf m) == TurboSmooth do
				(
					if firstCheck do
					(
						deleteModifier obj m
						firstCheck = not rolloutAdjustTurbosmooth.chk_firstinstance.checked
					)
				)
			)
		)
	)
	
	fn rearrange_turbosmooth_stack = (
		-- Rearrange turbosmooth modifiers to the top of the stack of selected objects
		-- Snippet reworked from bobo
		local collection = getCurrentSelection() -- Get the current sel
		if collection.count > 0 do -- Only continue if a selection has been done
		(
			-- Loop through each objects
			for obj in collection do
			(
				local firstCheck = true
				local aMods = #()
				if (rolloutAdjustTurbosmooth.chk_firstinstance.checked) then
				(
					for i = 1 to obj.modifiers.count where classof obj.modifiers[i] == TurboSmooth do
					(
						if firstCheck do
							append aMods #(i, obj.modifiers[i])
						firstCheck = false
					)
				) else (
					aMods = for i = obj.modifiers.count to 1 by -1 where classof obj.modifiers[i] == TurboSmooth collect #(i, obj.modifiers[i])
				)
				for m in aMods do 
					deleteModifier obj m[1] -- delete found turbosmooth modifiers
				for m in aMods do
					addModifier obj m[2] -- add the deleted modifiers to the top
			)
		)
	)
	
	fn initiate_ui = (
		local b = getINISetting sPathINI "Settings_AdjustTurbosmooth" "firstinstance"
		rolloutAdjustTurbosmooth.chk_firstinstance.checked = if (b == "" or b == "0") then false else true
	)
	
	rollout rolloutAdjustTurbosmooth "Adjust Turbosmooth" width:130 height:137
	(
		GroupBox 'grp_iterations' "Adjust Turbosmooth" pos:[2,2] width:126 height:106 align:#left
		label 'lbl_setall' "Set iterations:" pos:[7,20] width:79 height:14 align:#left
		spinner 'spn_iterations' "" pos:[84,19] width:38 height:16 range:[0,iMaxIterations,1] type:#integer scale:1 align:#left
		label 'lbl_adjustcurrent' "Adjust current:" pos:[7,41] width:75 height:14 align:#left
		button 'btn_increase' "+" pos:[88,41] width:16 height:16 align:#left
		button 'btn_decrease' "-" pos:[108,41] width:16 height:16 align:#left
		checkbox 'chk_firstinstance' "Only first instance" pos:[7,61] width:112 height:15 align:#left
		button 'btn_delete' "Delete Turbosmooth" pos:[5,82] width:120 height:22 toolTip:"Click to delete turbosmooth modifiers from selected objects" align:#left
		button 'btn_movetotop' "Move to top" pos:[5,111] width:120 height:22 toolTip:"Click to move all turbosmooth on selected object to the top of the stack" align:#left

		on rolloutAdjustTurbosmooth close do
		(
			-- Save dialog current position to ini
			local aDialogPosition = (GetDialogPos rolloutAdjustTurbosmooth)
			setINISetting sPathINI "Settings_AdjustTurbosmooth" "rollout_pos_x" ((aDialogPosition[1] as Integer) as string)
			setINISetting sPathINI "Settings_AdjustTurbosmooth" "rollout_pos_y" ((aDialogPosition[2] as Integer) as string)
		)
		on spn_iterations changed bState do
		(
			undo "Set Turbosmooth Iteration" on
				adjust_iterations bState true
		)
		on btn_increase pressed do
		(
			undo "Increase Turbosmooth Iteration" on
				adjust_iterations 1 false
		)
		on btn_decrease pressed do
		(
			undo "Decrease Turbosmooth Iteration" on
				adjust_iterations -1 false
		)
		on chk_firstinstance changed bState do
		(
			setINISetting sPathINI "Settings_AdjustTurbosmooth" "firstinstance" (if bState then "1" else "0")
		)
		on btn_delete pressed do
		(
			local q = "Do you want to delete turbosmooth from selected objects?"
			if (rolloutAdjustTurbosmooth.chk_firstinstance.checked) do
				q += "\n(Only the first turbosmooth modifier will be delete per object)"
			if (queryBox q title:"Confirm delete turbosmooth") do
			(
				undo "Delete Turbosmooth on selection" on (
					delete_turbosmooth()
				)
			)
		)
		on btn_movetotop pressed do
		(
			local q = "Do you want to move turbosmooth modifier to the top of the stack on selected objects?"
			if (rolloutAdjustTurbosmooth.chk_firstinstance.checked) do
				q += "\n(Only the first turbosmooth modifier will be moved per object)"
			if (queryBox q title:"Confirm rearranging turbosmooth modifiers") do
			(
				undo "Rearrange Turbosmooth on selection" on (
					rearrange_turbosmooth_stack()
				)
			)
		)
	)

	try(destroyDialog rolloutAdjustTurbosmooth)catch()	
	createdialog rolloutAdjustTurbosmooth 130 137 iRolloutPosX iRolloutPosY lockHeight:true
	initiate_ui()
)
