macroScript Mass_PolyMatID_Replace
 	category: "AKNToolkit"
 	toolTip: "Replace Mat IDs on selected objects"
 	buttonText: "MassReplaceMatID"
 	icon: #("AKNToolkit",3)
(
	try destroyDialog replacematidRollout catch()
	
	fn check_obj obj = (
		local ret = #(undefined, undefined)
		-- check if the object has any modifiers on it
		if (classOf obj.modifiers[1] == UndefinedClass) then (
			-- Object has no modifiers, check if the object is editable poly or mesh
			if (classOf obj == Editable_Poly or classOf obj == Editable_Mesh) then (
				-- Object is an Editable Poly/Mesh, set that as the object to do changes to
				ret = #(obj, 0)
			)
		) else (
			-- Modifiers detected, check if there is an editable poly modifier on the object, and use the first one to do changes to
			local notfound = true
			for i = 1 to obj.modifiers.count while notfound do (
				if ((classOf obj.modifiers[i] == Edit_Poly) and notfound == true) do (
					notfound = false	
					ret = #(i, 1)
				)
			)
		)
		if ret[1] == undefined do (
			x = queryBox ("The object, "+obj.name+", isn't an Editable Poly and doesn't have an Edit Poly modifier assigned to it.\nDo you want to add an edit poly modifier to it? Press No to skip the object)") title:"Missing editables"
			if (x == true) do (
				addmodifier obj (Edit_Poly())
				ret = #(1, 1)
			)
		)
		ret
	)
	
	fn replace_matids matid1 matid2 replaceall = (
		local collection = getCurrentSelection()

		for obj in collection do (
			local stack_mat = #(undefined, undefined) --  obj, type	
			-- check if the object has any modifiers on it.
			local stackaction = replacematidRollout.ddl_noteditable.selection

			if stackaction == 1 then (
				-- Check if there is a valid base mesh or already existing modifier to edit
				stack_mat = check_obj obj
			) else if stackaction == 2 then (
				addmodifier obj (Edit_Poly())
				stack_mat = #(1, 1)
			) else if stackaction == 3 then (
				convertTo obj Editable_Poly
				stack_mat = #(0, 0)
			) else if stackaction == 4 then (
				convertTo obj Editable_Mesh
				stack_mat = #(0, 0)
			)
			
			-- Check if the editable stack object is the basemesh
			if (stack_mat[1] != undefined and stack_mat[2] == 0) then (
				-- Check if it's a editable poly or editable mesh and change the material ids
				case classOf obj of (
					editable_poly: (
						for f = 1 to obj.numfaces do (
							if (polyop.getFaceMatID obj f) == matid1 or replaceall == true do (
								polyop.setFaceMatID obj f matid2
							)
						)
					)
					editable_mesh: (
						for f = 1 to obj.numfaces do (
							if getFaceMatID obj f == matid1 or replaceall == true do (
								setFaceMatID obj f matid2
							)
						)
					)
				)
				update obj
			) else if (stack_mat[1] != undefined and stack_mat[2] == 1) then (
				-- Change to the closest edit poly modifier and edit the material ids
				if (classOf obj.modifiers[stack_mat[1]] == Edit_Poly) then (
					modPanel.setCurrentObject obj.modifiers[stack_mat[1]]
					subobjectLevel = 4
					obj.modifiers[stack_mat[1]].SetSelection #Face #{}
					if (replaceall == true) then (
						obj.modifiers[stack_mat[1]].SetSelection #Face #{1..polyOp.getNumFaces obj}
					) else (
						obj.modifiers[stack_mat[1]].selectByMaterialID = matid1-1
					)
					obj.modifiers[stack_mat[1]].ButtonOp #SelectByMaterial
					obj.modifiers[stack_mat[1]].SetOperation #SetMaterial
					obj.modifiers[stack_mat[1]].materialIDToSet = matid2-1
					obj.modifiers[stack_mat[1]].Commit ()
					subobjectLevel = 0
				)
				clearSelection()
			)
		)
		-- Select all the objects again
		selectmore collection
	)
	
	rollout replacematidRollout "Replace MatIDs"
	(
		groupBox 'grp_Action' "Replace matIDs on..." pos:[2,2] width:166 height:40\
		dropDownList 'ddl_noteditable' "" pos:[8,18] width:154 height:40\
			items:#("Use closest modifier/base mesh", "Added Edit Poly", "Collapsed to Editable Poly", "Collapsed to Editable Mesh") align:#left
		groupBox 'grp_switchmatid' "Switch MatID..." pos:[2,46] width:166 height:62 align:#left
		spinner 'spn_matid_from' "from:" pos:[6,65] width:47 height:16 range:[1,20,1] type:#integer scale:1 align:#left
		button 'btn_switch' "<>" pos:[73,65] width:22 height:16 align:#left
		spinner 'spn_matid_to' "to: " pos:[102,65] width:51 height:16 range:[1,20,1] type:#integer scale:1 align:#left
		checkbox 'chk_replaceall' "Change all polygons?" pos:[6,86] width:150 height:18
		button 'btn_replace' "Replace" pos:[50,112] width:70 height:24 align:#center
		
		on btn_replace pressed do (
			if (selection.count > 0) do (
				if (chk_replaceall.checked == true) then (
					if (queryBox ("Are you sure you want to replace all faces on selected objects with mat id "+replacematidRollout.spn_matid_to.value as string+"?") title:"Confirm replace") do (
						undo "Replace MatIDs" on (
							replace_matids replacematidRollout.spn_matid_from.value replacematidRollout.spn_matid_to.value true
						)
					)
				) else (
					undo "Replace MatIDs" on (
						replace_matids replacematidRollout.spn_matid_from.value replacematidRollout.spn_matid_to.value false
					)
				)
			)
		)
		on btn_switch pressed do (
			-- Switch the "to" and "from" values with each another
			swap replacematidRollout.spn_matid_from.value replacematidRollout.spn_matid_to.value
		)
		on chk_replaceall changed state do (
			replacematidRollout.spn_matid_from.enabled = not state
		)
	)
	
	
	createdialog replacematidRollout 170 140 100 100 lockHeight:true
)
