macroScript No_Smooth_ID_Detection
 	category: "AKNToolkit"
 	toolTip: "Find objects with polygons with no smoothing ID"
 	buttonText: "NoSmoothingID"
 	icon: #("AKNToolkit",5)
(
	local objs = if (getCurrentSelection()).count == 0 then (objects) else (getCurrentSelection())

	fn check_obj obj = (
		local ret = #(undefined, undefined)
		-- check if the object has any modifiers on it
		if (classOf obj.modifiers[1] == UndefinedClass) then (
			-- Object has no modifiers, check if the object is editable poly or mesh
			if ((classOf obj) == Editable_Poly or (classOf obj) == Editable_Mesh) do
			(
				-- Object is an Editable Poly/Mesh, set that as the object to do changes to
				ret = #(obj, 0)
			)
		) else (
			-- Modifiers detected, check if there is an editable poly modifier on the object, and use the first one to do changes to
			local notfound = true
			for i = 1 to obj.modifiers.count while notfound do (
				if ((classOf obj.modifiers[i] == Edit_Poly) and notfound == true) do (
					notfound = false	
					ret = #(obj.modifiers[i], 1)
				)
			)
		)
		if ret[1] == undefined do (
			x = queryBox ("The object, "+obj.name+", isn't an Editable Poly and doesn't have an Edit Poly modifier assigned to it.\nDo you want to add an edit poly modifier to it? Press No to skip the object)") title:"Missing editables"
			if (x == true) do (
				addmodifier obj (Edit_Poly())
				ret = #(obj.modifiers[1], 1)
			)
		)
		ret
	)

	-- Returns the faces which has the submitted smoothing group
	fn getFacesWSG obj sg =
	(
		-- Obj: object to check,  sg: smoothing group to search for
		local foundsg = (for f = 1 to polyop.getNumFaces obj where polyop.getFaceSmoothGroup obj f == sg collect f)
		foundsg
	)

	local found_objs = #()

		-- More then one object was selected to be checked, now select only the ones with missing smoothing groups on faces
		for n in objs do
		(
			-- Check if there is any modifiers on the object
			local m = check_obj(n)
			format "%\n----------\n" (m as array)
			if (m[2] == 0) then
			(
				local found_faces = getFacesWSG m[1] 0
				if (found_faces.count > 0) do
				(
					append found_objs m[1]
					polyOp.setFaceSelection m[1] found_faces
				)
			) else if (m[2] != undefined) do (
				Format "Else\n"

			)
		)

		format "Found Objs: %\n" found_objs
		if found_objs.count > 0 do
		(
			max select none
			select (found_objs)
		)

		max views redraw
)