macroScript XForm_Seeker
 	category: "AKNToolkit"
 	toolTip: "XForm Seeker, find objects with nonuniform scaling/rotation"
 	buttonText: "XForm_Seeker"
 	icon: #("AKNToolkit",6)
(
	local rolloutXform

	fn find_xform_objects sAction = (
		local aObjs = getCurrentSelection()
		local bRot = rolloutXform.chk_rotation.checked
		local bScale = rolloutXform.chk_scaling.checked
		local aXformObjs = #()
		if (aObjs.count == 0) do
			aObjs = for n in objects collect n
		
		
		for n in aObjs do
		(
			if (bRot == true and (n.rotation.x != 0 or n.rotation.y != 0 or n.rotation.z != 0)) OR (bScale == true and n.scale != [1,1,1]) then
			(
				append aXformObjs n
			)
		)
		
		max select none
		if (aXformObjs.count == 0) then
		(
			-- No objects found, deselect objects in scene and display message
			messageBox "No objects found with rotation/scaling." title:"Result"
		) else (	
			-- Select found objects
			select aXformObjs
		)
	)
	
	fn apply_xform = if (getCurrentSelection()).count > 0 do (
		local aObjs = getCurrentSelection()
		if (queryBox ("Do you want to apply xform to "+aObjs.count as string +" object(s)?") title:"Confirm xform") do
		(
			resetxform aObjs
			if (rolloutXform.chk_collapse.checked) do
			(
				-- If selected, add an Editable Poly modifier, before collapsing
				if (rolloutXform.chk_convertpoly.checked) do
					addmodifier aObjs (Edit_Poly())
				-- Collapse the stack
				collapseStack aObjs
				
			)
		)
	)
	
	rollout rolloutXform "XForm Seeker" width:287 height:102
	(
		GroupBox 'grp_findobjectswith' "Find objects with ..." pos:[1,2] width:282 height:40 align:#left
		checkbox 'chk_rotation' "Rotation" pos:[10,20] width:71 height:17 checked:true align:#left
		checkbox 'chk_scaling' "Scaling" pos:[90,20] width:71 height:17 checked:true align:#left
		button 'btn_select' "Select" pos:[194,12] width:84 height:23 align:#left
		GroupBox 'grp4' "Apply XForm on selected" pos:[1,43] width:282 height:53 align:#left
		checkbox 'chk_collapse' "Collapse stack after apply xform?" pos:[10,58] width:180 height:18 align:#left checked:true
		checkbox 'chk_convertpoly' "Convert to editable poly?" pos:[10,76] width:180 height:18 align:#left checked:true
		button 'btn_apply_xform' "Apply XForm" pos:[194,60] width:84 height:23 align:#left
		
		on btn_select pressed do
		(
			find_xform_objects "select"
		)
		on btn_apply_xform pressed do with undo label:"apply xform" on
		(
			apply_xform()
		)
		
		on chk_collapse changed bState do
		(
			chk_convertpoly.enabled = bState
		)
	)
	-- Create the dialog and initate the ui values
	try(destroyDialog rolloutXform)catch()	
	createdialog rolloutXform 287 102 200 200 lockHeight:true
)
